@@ -342,7 +342,10 @@ char * SearchFTDB(FullTextDB db, char * String, char * FieldName,
 
 	while (Field)
 	{
-	    if (!Field->DoIndex) continue;
+	    if (!Field->DoIndex) {
+		Field = Field->Next;
+		continue;
+	    }
 
 	    rc = SearchFTDB(db, String, Field->Name, &PartialMatchList);
 	    if (rc)
@@ -429,7 +432,7 @@ static char * ReadCorrespondanceList(struct OneField * Field,
     struct PointerTableEntry Entry;
     unsigned int * Records;
     int i;
-    struct OneMatch * Curr;
+    struct OneMatch * Curr = NULL;
     struct Correspondance * CorTable;
     unsigned int Extra, Filesize;
     caddr_t Map;
@@ -480,7 +483,7 @@ static char * ReadCorrespondanceList(struct OneField * Field,
     
     Map = (void *) mmap(NULL, Filesize, PROT_READ, MAP_FILE | MAP_PRIVATE, 
 			Field->cfd, 0);
-    if ((int) Map == -1) return strerror(errno);
+    if (Map == (void *) -1) return strerror(errno);
 
     CorTable = (void *) ((char *) Map + Field->CorHeader.Unstructured);
         
@@ -589,7 +592,7 @@ static char * ReindexField(FullTextDB db, struct OneField * Field)
     
     Map = (char *) mmap(NULL, Filesize, PROT_READ | PROT_WRITE,
 			MAP_FILE | MAP_PRIVATE, Field->cfd, 0);
-    if ((int) Map == -1) 
+    if (Map == (char *) -1) 
     {
 	rc = strerror(errno);
 	unlink(Filename);
