@@ -1,22 +1,3 @@
-/*
-  FTDB database system
-  Copyright (C) 1995 Erik Troan, North Carolina State University
- 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-  
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-*/
-
 /* 
  * tkAppInit.c --
  *
@@ -33,6 +14,14 @@
 #include "tk.h"
 #include "ftdb_tcl.h"
 
+#if HAVE_LIBTCLX == 1
+#include "tclExtend.h"
+#endif
+
+#if HAVE_LIBTIX == 1
+int Tix_Init(Tcl_Interp * interp);
+#endif
+
 /*
  * The following variable is a special hack that is needed in order for
  * Sun shared libraries to be used for Tcl.
@@ -87,8 +76,7 @@ main(int argc, char ** argv)
  */
 
 int
-Tcl_AppInit(interp)
-    Tcl_Interp *interp;		/* Interpreter for application. */
+Tcl_AppInit(Tcl_Interp * interp)
 {
     if (Tcl_Init(interp) == TCL_ERROR) {
 	return TCL_ERROR;
@@ -108,8 +96,20 @@ Tcl_AppInit(interp)
      * where "Mod" is the name of the module.
      */
 
-    if (Tclftdb_Init(interp) == TCL_ERROR)
+#if HAVE_LIBTCLX == 1
+    if (TclX_Init(interp) == TCL_ERROR) {
         return TCL_ERROR;
+    }
+#endif
+#if HAVE_LIBTIX == 1
+    if (Tix_Init(interp) == TCL_ERROR) {
+        return TCL_ERROR;
+    }
+#endif
+
+    if (Ftdb_Init(interp) == TCL_ERROR) {
+        return TCL_ERROR;
+    }
 
     /*
      * Call Tcl_CreateCommand for application-specific commands, if
